@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: Component.c,v 1.58 2004/03/26 13:34:07 dk Exp $
+ * $Id: Component.c,v 1.59 2004/12/13 15:54:17 dk Exp $
  */
 
 #include "apricot.h"
@@ -740,7 +740,7 @@ XS( Component_notify_FROMPERL)
       void * ret;
       ret = hash_fetch( var-> eventIDs, name, nameLen);
       if ( ret != nil) {
-         list = var-> events + ( IV) ret - 1;
+         list = var-> events + PTR2UV( ret) - 1;
          seqCount += list-> count;
       }
    }
@@ -928,7 +928,7 @@ Component_add_notification( Handle self, char * name, SV * subroutine, Handle re
       ret = hash_fetch( var-> eventIDs, name, nameLen);
 
    if ( ret == nil) {
-      hash_store( var-> eventIDs, name, nameLen, ( void*)((IV) var-> eventIDCount + 1));
+      hash_store( var-> eventIDs, name, nameLen, INT2PTR(void*, var-> eventIDCount + 1));
       if ( var-> events == nil)
          var-> events = ( List*) malloc( sizeof( List));
       else {
@@ -940,7 +940,7 @@ Component_add_notification( Handle self, char * name, SV * subroutine, Handle re
       list = var-> events + var-> eventIDCount++;
       list_create( list, 2, 2);
    } else
-      list = var-> events + ( IV) ret - 1;
+      list = var-> events +  PTR2UV( ret) - 1;
 
    ret = ( void *) newSVsv( subroutine);
    index = list_insert_at( list, referer, index);
@@ -1026,7 +1026,7 @@ XS( Component_get_notification_FROMPERL)
    event = ( char *) SvPV( ST( 1), na);
    ret = hash_fetch( var-> eventIDs, event, strlen( event));
    if ( ret == nil) XSRETURN_EMPTY;
-   list = var-> events + ( IV) ret - 1;
+   list = var-> events + PTR2UV( ret) - 1;
 
    if ( items < 3) {
       int i;
@@ -1137,7 +1137,7 @@ Component_delegations( Handle self, Bool set, SV * delegations)
       while (( he = hv_iternext( var-> eventIDs)) != nil) {
          int i;
          char * event = ( char *) HeKEY( he);
-         PList list = var-> events + ( IV) HeVAL( he) - 1;
+         PList list = var-> events + PTR2UV( HeVAL( he)) - 1;
          for ( i = 0; i < list-> count; i += 2) {
             if ( list-> items[i] != last) {
                last = list-> items[i];
