@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: gp.c,v 1.22 2003/02/10 10:35:25 dk Exp $
+ * $Id: gp.c,v 1.26 2004/06/08 20:08:11 dk Exp $
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
 /* apc.c --- apc/ api for os/2 */
@@ -226,7 +226,7 @@ apc_gp_fill_chord ( Handle self, int x, int y,  int dX, int dY, double angleStar
    if ( !GpiBeginPath( sys ps, 1)) apiErr;
    if ( GpiPartialArc ( sys ps, &ptl, MAKEFIXED( 0, 0x8000), float2fixed(angleStart), float2fixed(angleEnd-angleStart)) == GPI_ERROR) apiErr;
    if ( !GpiEndPath( sys ps)) apiErr;
-   if ( GpiFillPath( sys ps, 1, FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
+   if ( GpiFillPath( sys ps, 1, sys fillWinding ? FPATH_WINDING : FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
    return true;
 }
 
@@ -252,7 +252,7 @@ apc_gp_fill_poly( Handle self, int numPts, Point * points)
    if ( !GpiBeginPath( sys ps, 1)) apiErr;
    if ( GpiPolyLine( sys ps, numPts - 1, ( PPOINTL)&points[1]) == GPI_ERROR) apiErr;
    if ( !GpiEndPath( sys ps)) apiErr;
-   if ( GpiFillPath( sys ps, 1, FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
+   if ( GpiFillPath( sys ps, 1, sys fillWinding ? FPATH_WINDING : FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
    return true;
 }
 
@@ -266,7 +266,7 @@ apc_gp_fill_sector ( Handle self, int x, int y,  int dX, int dY, double angleSta
    if ( GpiPartialArc ( sys ps, &ptl, MAKEFIXED( 0, 0x8000), float2fixed(angleStart), float2fixed(angleEnd-angleStart)) == GPI_ERROR) apiErr;
    if ( GpiLine( sys ps, &ptl) == GPI_ERROR) apiErr;
    if ( !GpiEndPath( sys ps)) apiErr;
-   if ( GpiFillPath( sys ps, 1, FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
+   if ( GpiFillPath( sys ps, 1, sys fillWinding ? FPATH_WINDING : FPATH_ALTERNATE) == GPI_ERROR) apiErrRet;
    return true;
 }
 
@@ -612,6 +612,8 @@ apc_gp_get_font_ranges( Handle self, int * count)
    *count = 2;
    ret[0] = fm. sFirstChar;
    ret[1] = fm. sLastChar;
+   if ( ret[0] > 255) ret[0] = 255;
+   if ( ret[1] > 255) ret[1] = 255;
    return ret;
 }
 
@@ -656,12 +658,31 @@ static int ctx_le2LINEEND [] = {
    endCtx
 };
 
+Bool
+apc_gp_get_fill_winding ( Handle self)
+{
+   return sys fillWinding;
+}
 
 int
 apc_gp_get_line_end ( Handle self)
 {
    if ( !sys ps) return sys lineEnd;
-   return ctx_remap_def( GpiQueryLineEnd( sys ps), ctx_le2LINEEND, false, leFlat);
+   return ctx_remap_def( GpiQueryLineEnd( sys ps), ctx_le2LINEEND, false, leRound);
+}
+
+static int ctx_lj2LINEJOIN [] = {
+   ljRound     ,  LINEJOIN_ROUND  ,
+   ljBevel     ,  LINEJOIN_BEVEL  ,
+   ljMiter     ,  LINEJOIN_MITRE  ,
+   endCtx
+};
+
+int
+apc_gp_get_line_join ( Handle self)
+{
+   if ( !sys ps) return sys lineJoin;
+   return ctx_remap_def( GpiQueryLineJoin( sys ps), ctx_lj2LINEJOIN, false, ljRound);
 }
 
 int
@@ -1020,6 +1041,13 @@ apc_gp_set_font( Handle self, PFont font)
    return true;
 }
 
+Bool
+apc_gp_set_fill_winding( Handle self, Bool fillWinding)
+{
+   sys fillWinding = fillWinding;
+   return true;
+}
+
 Bool
 apc_gp_set_line_end ( Handle self, int lineEnd)
 {
@@ -1029,6 +1057,15 @@ apc_gp_set_line_end ( Handle self, int lineEnd)
    return true;
 }
 
+Bool
+apc_gp_set_line_join( Handle self, int lineJoin)
+{
+   if ( !sys ps) { sys lineJoin = lineJoin; return true; }
+   if ( !GpiSetLineJoin( sys ps, ctx_remap_def( lineJoin, ctx_lj2LINEJOIN, true, LINEJOIN_DEFAULT)))
+      apiErrRet;
+   return true;
+}
+
 Bool
 apc_gp_set_line_width( Handle self, int lineWidth)
 {
