@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: misc.c,v 1.29 2003/07/28 09:27:34 dk Exp $
+ * $Id: misc.c,v 1.30 2003/10/31 10:48:25 dk Exp $
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
 #include "win32\win32guts.h"
@@ -410,7 +410,7 @@ apc_sys_get_value( int sysValue)
    case svCanUTF8_Input   : return HAS_WCHAR;
    case svCanUTF8_Output  : return HAS_WCHAR;
    default:
-      apcErr( errInvParams);
+      return -1;
    }
    return 0;
 }
